#!/bin/sh

fromspec=0
if [ $# -ne 1 ]; then
  if [ X$1 = "Xspec" ]; then
    fromspec=1
  fi
fi

#
# Build the driver.
#
if [ $fromspec -eq 0 ]; then
   make NVdriver || {
       echo Build error
       exit 1
   }
fi

# unload it quietly if already loaded..

    /sbin/rmmod NVdriver >/dev/null 2>&1

#
# Load the driver to get the major device numbers.
#
    /sbin/insmod ./NVdriver || {
        echo Error loading kernel driver
        echo Check build
        exit 1
    }

#
# Read device major numbers.
#
    set -- `cat /proc/devices | grep --word-regexp nvidia`
    nvnode=$1

#
# Create device nodes.
#
    for d in 0 1 2 3
    do
        devfile=/dev/nvidia$d
        rm -f $devfile
        mknod $devfile c $nvnode $d
        chmod 0666 $devfile
    done

    devfile=/dev/nvidiactl
    rm -f $devfile
    mknod $devfile c $nvnode 255
    chmod 0666 $devfile

#
# Automatically load the kernel module using kmod
# Add our line to /etc/conf.modules (after first deleting any older NVdriver lines)
#
    confmod="/etc/conf.modules"
    [ -f /etc/modules.conf ] && confmod="/etc/modules.conf"

    conftmp=/tmp/conf$$

    sed '/^alias.*char-major-.*NVdriver/d' < $confmod > $conftmp
    echo "alias char-major-$nvnode NVdriver" >> $conftmp
    mv $conftmp $confmod

#
# Add it to the module dependency list.
#
    mkdir -p /lib/modules/`uname -r`/video
    install NVdriver /lib/modules/`uname -r`/video
if [ $fromspec -eq 0 ]; then
    /sbin/depmod -a
fi


#
# It worked
#
if [ $fromspec -eq 0 ]; then
    echo
    echo NVdriver installed successfully
    echo
fi

    exit 0

